==> janis_pipelines.bioinformatics-0.10.4-py3-none-any.whl: janis_bioinformatics/tools/gatk4/__init__.py <==
from .applybqsr.versions import (
    Gatk4ApplyBqsr_4_0,
    Gatk4ApplyBqsr_4_1_2,
    Gatk4ApplyBqsr_4_1_3,
    Gatk4ApplyBqsr_4_1_4,
    Gatk4ApplyBqsrLatest,
)
from .baserecalibrator.versions import (
    Gatk4BaseRecalibrator_4_0,
    Gatk4BaseRecalibrator_4_1_2,
    Gatk4BaseRecalibrator_4_1_3,
    Gatk4BaseRecalibrator_4_1_4,
    Gatk4BaseRecalibratorLatest,
)
from .calculatecontaminations.versions import (
    Gatk4CalculateContamination_4_1_2,
    Gatk4CalculateContamination_4_1_3,
    Gatk4CalculateContamination_4_1_4,
    Gatk4CalculateContaminationLatest,
)
from .createsequencedictionary.versions import (
    Gatk4CreateSequenceDictionary_4_1_2,
    Gatk4CreateSequenceDictionary_4_1_3,
    Gatk4CreateSequenceDictionary_4_1_4,
    Gatk4CreateSequenceDictionaryLatest,
)
from .fastqtosam.versions import *
from .filtermutectcalls.versions import (
    Gatk4FilterMutectCalls_4_1_2,
    Gatk4FilterMutectCalls_4_1_3,
    Gatk4FilterMutectCalls_4_1_4,
    Gatk4FilterMutectCallsLatest,
)
from .gathervcfs.versions import (
    Gatk4GatherVcfs_4_0,
    Gatk4GatherVcfs_4_1_2,
    Gatk4GatherVcfs_4_1_3,
    Gatk4GatherVcfs_4_1_4,
    Gatk4GatherVcfsLatest,
)
from .genotypeconcordance.versions import (
    Gatk4GenotypeConcordance_4_0,
    Gatk4GenotypeConcordance_4_1_2,
    Gatk4GenotypeConcordance_4_1_3,
    Gatk4GenotypeConcordance_4_1_4,
    Gatk4GenotypeConcordanceLatest,
)
from .getpileupsummaries.versions import (
    Gatk4GetPileUpSummaries_4_1_2,
    Gatk4GetPileUpSummaries_4_1_3,
    Gatk4GetPileUpSummaries_4_1_4,
    Gatk4GetPileUpSummariesLatest,
)
from .haplotypecaller.versions import (
    Gatk4HaplotypeCaller_4_0,
    Gatk4HaplotypeCaller_4_1_2,
    Gatk4HaplotypeCaller_4_1_3,
    Gatk4HaplotypeCaller_4_1_4,
    Gatk4HaplotypeCallerLatest,
)
from .learnreadorientationmodel.versions import (
    Gatk4LearnReadOrientationModel_4_1_2,
    Gatk4LearnReadOrientationModel_4_1_3,
    Gatk4LearnReadOrientationModel_4_1_4,
    Gatk4LearnReadOrientationModelLatest,
)
from .markduplicates.versions import (
    Gatk4MarkDuplicates_4_0,
    Gatk4MarkDuplicates_4_1_2,
    Gatk4MarkDuplicates_4_1_3,
    Gatk4MarkDuplicates_4_1_4,
    Gatk4MarkDuplicatesLatest,
)
from .mergebamalignment.versions import *
from .mergemutectstats.versions import (
    Gatk4MergeMutectStats_4_1_2,
    Gatk4MergeMutectStats_4_1_3,
    Gatk4MergeMutectStats_4_1_4,
    Gatk4MergeMutectStatsLatest,
)
from .mergesamfiles.versions import (
    Gatk4MergeSamFiles_4_0,
    Gatk4MergeSamFiles_4_1_2,
    Gatk4MergeSamFiles_4_1_3,
    Gatk4MergeSamFiles_4_1_4,
    Gatk4MergeSamFilesLatest,
)
from .mutect2.versions import (
    GatkMutect2_4_0,
    GatkMutect2_4_1_2,
    GatkMutect2_4_1_3,
    GatkMutect2_4_1_4,
    GatkMutect2Latest,
)
from .printreads.versions import (
    Gatk4PrintReads_4_0,
    Gatk4PrintReads_4_1_2,
    Gatk4PrintReads_4_1_3,
    Gatk4PrintReads_4_1_4,
    Gatk4PrintReadsLatest,
)
from .selectvariants.versions import (
    Gatk4SelectVariants_4_0,
    Gatk4SelectVariants_4_1_2,
    Gatk4SelectVariants_4_1_3,
    Gatk4SelectVariants_4_1_4,
    Gatk4SelectVariantsLatest,
)
from .sortsam.versions import (
    Gatk4SortSam_4_0,
    Gatk4SortSam_4_1_2,
    Gatk4SortSam_4_1_3,
    Gatk4SortSam_4_1_4,
    Gatk4SortSamLatest,
)
from .splitreads.versions import (
    Gatk4SplitReadsLatest,
    Gatk4SplitReads_4_1_2,
    Gatk4SplitReads_4_1_3,
    Gatk4SplitReads_4_1_4,
)

from .collectinsertsizemetrics.versions import (
    Gatk4CollectInsertSizeMetrics_4_1_2,
    Gatk4CollectInsertSizeMetrics_4_1_3,
    Gatk4CollectInsertSizeMetrics_4_1_4,
    Gatk4CollectInsertSizeMetricsLatest,
)

from .setnmmdanduqtags.versions import (
    Gatk4SetNmMdAndUqTags_4_1_3,
    Gatk4SetNmMdAndUqTags_4_1_4,
    Gatk4SetNmMdAndUqTagsLatest,
)

from .gatherbqsrreports.versions import (
    Gatk4GatherBQSRReports_4_1_2,
    Gatk4GatherBQSRReports_4_1_3,
    Gatk4GatherBQSRReports_4_1_4,
    Gatk4GatherBQSRReportsLatest,
)

from .gatherbamfiles.versions import (
    Gatk4GatherBamFiles_4_1_2,
    Gatk4GatherBamFiles_4_1_3,
    Gatk4GatherBamFiles_4_1_4,
    Gatk4GatherBamFilesLatest,
)

from .depthofcoverage.versions import (
    Gatk4DepthOfCoverage_4_1_6,
    Gatk4DepthOfCoverageLatest,
)

from .splitncigarreads.versions import *
from .addorreplacereadgroups.versions import *
from .reordersam.versions import *

==> janis_pipelines.bioinformatics-0.11.3-py3-none-any.whl: janis_bioinformatics/tools/gatk4/__init__.py <==
from .applybqsr.versions import (
    Gatk4ApplyBqsr_4_0,
    Gatk4ApplyBqsr_4_1_2,
    Gatk4ApplyBqsr_4_1_3,
    Gatk4ApplyBqsr_4_1_4,
    Gatk4ApplyBqsrLatest,
)
from .baserecalibrator.versions import (
    Gatk4BaseRecalibrator_4_0,
    Gatk4BaseRecalibrator_4_1_2,
    Gatk4BaseRecalibrator_4_1_3,
    Gatk4BaseRecalibrator_4_1_4,
    Gatk4BaseRecalibratorLatest,
)
from .calculatecontaminations.versions import (
    Gatk4CalculateContamination_4_1_2,
    Gatk4CalculateContamination_4_1_3,
    Gatk4CalculateContamination_4_1_4,
    Gatk4CalculateContaminationLatest,
)
from .createsequencedictionary.versions import (
    Gatk4CreateSequenceDictionary_4_1_2,
    Gatk4CreateSequenceDictionary_4_1_3,
    Gatk4CreateSequenceDictionary_4_1_4,
    Gatk4CreateSequenceDictionaryLatest,
)
from .fastqtosam.versions import *
from .filtermutectcalls.versions import (
    Gatk4FilterMutectCalls_4_1_2,
    Gatk4FilterMutectCalls_4_1_3,
    Gatk4FilterMutectCalls_4_1_4,
    Gatk4FilterMutectCallsLatest,
)
from .gathervcfs.versions import (
    Gatk4GatherVcfs_4_0,
    Gatk4GatherVcfs_4_1_2,
    Gatk4GatherVcfs_4_1_3,
    Gatk4GatherVcfs_4_1_4,
    Gatk4GatherVcfsLatest,
)
from .genotypeconcordance.versions import (
    Gatk4GenotypeConcordance_4_0,
    Gatk4GenotypeConcordance_4_1_2,
    Gatk4GenotypeConcordance_4_1_3,
    Gatk4GenotypeConcordance_4_1_4,
    Gatk4GenotypeConcordanceLatest,
)
from .getpileupsummaries.versions import (
    Gatk4GetPileUpSummaries_4_1_2,
    Gatk4GetPileUpSummaries_4_1_3,
    Gatk4GetPileUpSummaries_4_1_4,
    Gatk4GetPileUpSummariesLatest,
)
from .haplotypecaller.versions import *
from .learnreadorientationmodel.versions import (
    Gatk4LearnReadOrientationModel_4_1_2,
    Gatk4LearnReadOrientationModel_4_1_3,
    Gatk4LearnReadOrientationModel_4_1_4,
    Gatk4LearnReadOrientationModelLatest,
)
from .markduplicates.versions import (
    Gatk4MarkDuplicates_4_0,
    Gatk4MarkDuplicates_4_1_2,
    Gatk4MarkDuplicates_4_1_3,
    Gatk4MarkDuplicates_4_1_4,
    Gatk4MarkDuplicatesLatest,
)
from .mergebamalignment.versions import *
from .mergemutectstats.versions import (
    Gatk4MergeMutectStats_4_1_2,
    Gatk4MergeMutectStats_4_1_3,
    Gatk4MergeMutectStats_4_1_4,
    Gatk4MergeMutectStatsLatest,
)
from .mergesamfiles.versions import (
    Gatk4MergeSamFiles_4_0,
    Gatk4MergeSamFiles_4_1_2,
    Gatk4MergeSamFiles_4_1_3,
    Gatk4MergeSamFiles_4_1_4,
    Gatk4MergeSamFilesLatest,
)
from .mutect2.versions import *
from .printreads.versions import (
    Gatk4PrintReads_4_0,
    Gatk4PrintReads_4_1_2,
    Gatk4PrintReads_4_1_3,
    Gatk4PrintReads_4_1_4,
    Gatk4PrintReadsLatest,
)
from .selectvariants.versions import (
    Gatk4SelectVariants_4_0,
    Gatk4SelectVariants_4_1_2,
    Gatk4SelectVariants_4_1_3,
    Gatk4SelectVariants_4_1_4,
    Gatk4SelectVariantsLatest,
)
from .sortsam.versions import (
    Gatk4SortSam_4_0,
    Gatk4SortSam_4_1_2,
    Gatk4SortSam_4_1_3,
    Gatk4SortSam_4_1_4,
    Gatk4SortSamLatest,
)
from .splitreads.versions import (
    Gatk4SplitReadsLatest,
    Gatk4SplitReads_4_1_2,
    Gatk4SplitReads_4_1_3,
    Gatk4SplitReads_4_1_4,
)

from .collectinsertsizemetrics.versions import (
    Gatk4CollectInsertSizeMetrics_4_1_2,
    Gatk4CollectInsertSizeMetrics_4_1_3,
    Gatk4CollectInsertSizeMetrics_4_1_4,
    Gatk4CollectInsertSizeMetricsLatest,
)

from .setnmmdanduqtags.versions import (
    Gatk4SetNmMdAndUqTags_4_1_3,
    Gatk4SetNmMdAndUqTags_4_1_4,
    Gatk4SetNmMdAndUqTagsLatest,
)

from .gatherbqsrreports.versions import (
    Gatk4GatherBQSRReports_4_1_2,
    Gatk4GatherBQSRReports_4_1_3,
    Gatk4GatherBQSRReports_4_1_4,
    Gatk4GatherBQSRReportsLatest,
)

from .gatherbamfiles.versions import (
    Gatk4GatherBamFiles_4_1_2,
    Gatk4GatherBamFiles_4_1_3,
    Gatk4GatherBamFiles_4_1_4,
    Gatk4GatherBamFilesLatest,
)

from .depthofcoverage.versions import (
    Gatk4DepthOfCoverage_4_1_6,
    Gatk4DepthOfCoverageLatest,
)

from .splitncigarreads.versions import *
from .addorreplacereadgroups.versions import *
from .reordersam.versions import *
